***********************************************************************************************************************************************
*** Replication code for "Parties, Brokers and Voter Mobilization: How Turnout Buying Depends Upon the Party's Capacity to Monitor Brokers" ***
*** Date: 23/3/14                                                                                                                           ***
***********************************************************************************************************************************************



use Replication_Data.dta, clear



***************************** MAIN PAPER RESULTS *******************************

*****************************************
***          Vote choice plot         ***
*****************************************

*** Figure 2

twoway (function y = 4-x/2, range(0 5) lcolor(black)) (function y = 1.5+x/2, range(0 5) lcolor(black) lpattern(shortdash)), ///
  legend(rows(1) label(1 "A-biased voter density (b(d)>0)") label(2 "B-biased voter density (b(d)<0)") region(fcolor(white) lcolor(white))) ylabel(none, nogrid) xline(1.25 2.5 3.75, lpattern(dash) lcolor(black)) yscale(range(0.5 5)) ///
  ytitle(Density of voters) xtitle(Valence shock toward party B) xlabel(0 "-(2{&psi}){sup:-1}" 1.25 "-c(d,0)" 2.5 "0" 3.75 "c(d,0)" 5 "(2{&psi}){sup:-1}") subtitle(, color(black) fcolor(white) lcolor(white)) ///
  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

  
  
*****************************************
***         Summary statistics        ***
*****************************************

*** Table 1 in Online Appendix

quietly reg turnout share_pri_ln share_pan_ln share_prd_ln lista_nominal total_lista_nominal running discontinuity year if running>-20 & running<=20
sum turnout share_pri_ln share_pan_ln share_prd_ln lista_nominal total_lista_nominal running discontinuity year weighted_distance if e(sample)==1
quietly reg turnout share_pri_ln share_pan_ln share_prd_ln lista_nominal total_lista_nominal running discontinuity year
sum turnout share_pri_ln share_pan_ln share_prd_ln lista_nominal total_lista_nominal running discontinuity year weighted_distance if e(sample)==1



*****************************************
***         Theory motivation         ***
*****************************************

*** Proportion of polling stations and electoral precincts where there are 3 large parties
g comp = share_pan>0.2 & share_pri>0.2 & share_prd>0.2
summ comp
drop comp
preserve
collapse (mean) share_pan share_pri share_prd, by(year id_estado seccion)
g comp = share_pan>0.2 & share_pri>0.2 & share_prd>0.2
summ comp
drop comp
restore



*** Turnout and vote share by distance (Figure 3)
twoway (scatter turnout weighted_distance, msize(tiny) mcolor(gray)) ///
  (lfit turnout weighted_distance, clwidth(thick) lcolor(black)), ///
  legend(off) ylabel(, nogrid) ytitle(Turnout) xtitle(Average distance to polling station (km)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) title("Panel A: Turnout", color(black))
graph save Graph "g1.gph", replace
twoway (scatter share_pri weighted_distance, msize(tiny) mcolor(gray)) ///
  (lfit share_pri_ln weighted_distance, clwidth(thick) lcolor(black)), ///
  legend(off) ylabel(, nogrid) ytitle(PRI vote share) xtitle(Average distance to polling station (km)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) title("Panel B: PRI", color(black)) 
graph save Graph "g2.gph", replace
twoway (scatter share_pan weighted_distance, msize(tiny) mcolor(gray)) ///
  (lfit share_pan_ln weighted_distance if weighted_distance<=11, clwidth(thick) lcolor(black)), ///
  legend(off) ylabel(, nogrid) ytitle(PAN vote share) xtitle(Average distance to polling station (km)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) title("Panel C: PAN", color(black)) 
graph save Graph "g3.gph", replace
twoway (scatter share_prd weighted_distance, msize(tiny) mcolor(gray)) ///
  (lfit share_prd_ln weighted_distance, clwidth(thick) lcolor(black)), ///
  legend(off) ylabel(, nogrid) ytitle(PRD vote share) xtitle(Average distance to polling station (km)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) title("Panel D: PRD", color(black)) 
graph save Graph "g4.gph", replace

graph combine "g1" "g2" "g3" "g4", rows(2) cols(2) subtitle(, color(black) fcolor(white) lcolor(white)) ///
  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
capture graph export "C:\Users\John\Dropbox\Discontinuity\Paper Writing\voting_by_distance.pdf", as(pdf) replace
capture graph export "C:\Users\jmarshall\Dropbox\Discontinuity\Paper Writing\voting_by_distance.pdf", as(pdf) replace

erase "g1.gph" 
erase "g2.gph" 
erase "g3.gph" 
erase "g4.gph" 



*** Regression support for these correlations
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' weighted_distance, cluster(id_estado) a(id_district_year)
}
estout, cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(weighted_distance)



*****************************************
***          Maimonides plot          ***
*****************************************

*** Plot with real data (Figure 4)
twoway (scatter polling_stations total_lista_nominal if total_lista_nominal<=10500 & unique==1, msize(vsmall) mcolor(black)) ///
  (kdensity total_lista_nominal if total_lista_nominal<=10500 & unique==1, yaxis(2) lcolor(gray)), ///
  xlabel(0(750)10500, labsize(small)) legend(off) ylabel(, nogrid) ytitle(Number of polling stations (black)) ///
  ytitle(Density (grey), axis(2)) xtitle(Number of registered voters) xline(0(750)10500, lpattern(dash) lcolor(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))



*****************************************
***           Balance tests           ***
*****************************************

*** McCrary sorting tests (Figure 5) - need to install DCdensity ado file!
quietly foreach n of numlist 750 1500 2250 3000 3750 4500 {
  noisily DCdensity total_lista_nominal if unique==1, breakpoint(`n') b(1) h(5) generate(Xj Yj r0 fhat se_fhat)
  drop Xj Yj r0 fhat se_fhat
}

hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal<800, frequency fcolor(gray) lcolor(white) ///
  xline(750.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel A: 750-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g1.gph", replace
hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal>1400 & total_lista_nominal<1600, frequency fcolor(gray) lcolor(white) ///
  xline(1500.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel B: 1500-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g2.gph", replace
hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal>2000 & total_lista_nominal<2500, frequency fcolor(gray) lcolor(white) ///
  xline(2250.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel C: 2250-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g3.gph", replace
hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal>2900 & total_lista_nominal<3200, frequency fcolor(gray) lcolor(white) ///
  xline(3000.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel D: 3000-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g4.gph", replace
hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal>3700 & total_lista_nominal<3800, frequency fcolor(gray) lcolor(white) ///
  xline(3750.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel E: 3750-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g5.gph", replace
hist total_lista_nominal if unique==1 & running>-20 & running<=20 & total_lista_nominal>4400 & total_lista_nominal<4600, frequency fcolor(gray) lcolor(white) ///
  xline(4500.5, lpattern(dash) lcolor(black)) discrete legend(off) ylabel(, nogrid) ytitle(Frequency) xtitle(Number of registered voters) ///
  title("Panel F: 4500-voter discontinuity", color(black)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g6.gph", replace
  
graph combine "g1" "g2" "g3" "g4" "g5" "g6", rows(3) cols(2) subtitle(, color(black) fcolor(white) lcolor(white)) ///
  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
capture graph export "C:\Users\John\Dropbox\Discontinuity\Paper Writing\bunching.pdf", as(pdf) replace
capture graph export "C:\Users\jmarshall\Dropbox\Discontinuity\Paper Writing\bunching.pdf", as(pdf) replace

erase "g1.gph" 
erase "g2.gph" 
erase "g3.gph" 
erase "g4.gph" 
erase "g5.gph" 
erase "g6.gph" 



*** Balance over political, geographic and Census variables (Table 1)
eststo clear
quietly foreach y of varlist lag_pri lag_pan lag_prd log_area voter_density weighted_distance share_pea share_occupied {
  eststo, title("`y'"): areg `y' discontinuity if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)

eststo clear
quietly foreach y of varlist share_soc_sec illiterate_above_15 pri_inc-share_viv_part_hab share_viv_all {
  eststo, title("`y'"): areg `y' discontinuity if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)

eststo clear
quietly foreach y of varlist share_viv_radio-share_viv_inter {
  eststo, title("`y'"): areg `y' discontinuity if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)

foreach y of varlist lag_pri lag_pan lag_prd log_area voter_density weighted_distance share_pea-share_soc_sec illiterate_above_15 pri_inc-share_viv_part_hab share_viv_all-share_viv_inter {
  bysort runbin5 : egen `y'_runbin5 = mean(`y') if running>=-375 & running<=375
  twoway (scatter `y'_runbin5 runbin5 if running>=-375 & running<=375, mcolor(gray)) ///
  (lfit `y'_runbin5 runbin5 if running>=-375 & running<=0, lcolor(black) clwidth(thick)) ///
  (lfit `y'_runbin5 runbin5 if running>=0 & running<=375, lcolor(black) clwidth(thick)), ///
  xline(0, lwidth(thick)) legend(off) ylabel(, nogrid) ytick(#3) ytitle("") xtitle("Number of voters from splitting") title("`y'", color(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
  drop `y'_runbin5
  graph save Graph "g_`y'.gph", replace
}
graph combine "g_lag_pri_share_ln" "g_lag_pan_share_ln" "g_lag_prd_share_ln" "g_log_area" "g_voter_density" "g_weighted_distance" "g_share_pea" ///
  "g_share_occupied" "g_share_soc_sec" "g_illiterate_above_15" "g_pri_inc" "g_pri_com" "g_sec_inc" "g_sec_com" "g_share_viv_part_hab" "g_share_viv_all" ///
  "g_share_viv_radio" "g_share_viv_tv" "g_share_viv_refri" "g_share_viv_wash" "g_share_viv_car" "g_share_viv_tel" "g_share_viv_cel" "g_share_viv_inter", ///
  rows(6) cols(5) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

foreach x in "g_lag_pri_share_ln" "g_lag_pan_share_ln" "g_lag_prd_share_ln" "g_log_area" "g_voter_density" "g_weighted_distance" "g_share_pea" ///
  "g_share_occupied" "g_share_soc_sec" "g_share_soc_sec_imss" "g_share_soc_sec_iste" "g_share_soc_sec_istee" "g_share_soc_sec_seg_pop" "g_prim_sch_att" ///
  "g_mid_sch_att" "g_sec_sch_att" "g_pms_sch_att" "g_post_sch_att" "g_no_schooling_above_15" "g_pri_inc" "g_pri_com" "g_sec_inc" "g_sec_com" "g_share_viv_part_hab" "g_share_viv_all" ///
  "g_share_viv_radio" "g_share_viv_tv" "g_share_viv_refri" "g_share_viv_wash" "g_share_viv_car" "g_share_viv_tel" "g_share_viv_cel" "g_share_viv_inter" {
  capture erase "`x'.gph"
}



*** Distribution of polling stations by treatment across state and year (Tables 2 and 3 in the Online Appendix)
tab state_name discontinuity if running>-20 & running<=20
tab state_name discontinuity

tab year discontinuity if running>-20 & running<=20
tab year discontinuity



*****************************************
***             Main results          ***
*****************************************

*** All specifications include district-year fixed effects, and block bootstrap SEs by state

*** Graphical RD results (Figure 7)
preserve
foreach x of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  bysort runbin5 : egen `x'_runbin5 = mean(`x')
}
duplicates drop turnout_runbin5, force
twoway (scatter turnout_runbin5 runbin5 if running>=-375 & running<=375, mcolor(gray)) ///
  (lfit turnout_runbin5 runbin5 if running>=-375 & running<=0, lcolor(black) clwidth(thick)) ///
  (lfit turnout_runbin5 runbin5 if running>=0 & running<=375, lcolor(black) clwidth(thick)), ///
  xline(0, lwidth(thick) lpattern(dash) lcolor(black)) legend(off) ylabel(, nogrid) ytitle(Turnout) xtitle(Number of voters from splitting) title("Panel A: turnout", color(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g1.gph", replace
twoway (scatter share_pan_ln_runbin5 runbin5 if running>=-375 & running<=375, mcolor(gray)) ///
  (lfit share_pan_ln_runbin5 runbin5 if running>=-375 & running<=0, lcolor(black) clwidth(thick)) ///
  (lfit share_pan_ln_runbin5 runbin5 if running>=0 & running<=375, lcolor(black) clwidth(thick)), ///
  xline(0, lwidth(thick) lpattern(dash) lcolor(black)) legend(off) ylabel(, nogrid) ytitle(PAN vote share) xtitle(Number of voters from splitting) title("Panel C: PAN", color(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g2.gph", replace
twoway (scatter share_pri_ln_runbin5 runbin5 if running>=-375 & running<=375, mcolor(gray)) ///
  (lfit share_pri_ln_runbin5 runbin5 if running>=-375 & running<=0, lcolor(black) clwidth(thick)) ///
  (lfit share_pri_ln_runbin5 runbin5 if running>=0 & running<=375, lcolor(black) clwidth(thick)), ///
  xline(0, lwidth(thick) lpattern(dash) lcolor(black)) legend(off) ylabel(, nogrid) ytitle(PRI vote share) xtitle(Number of voters from splitting) title("Panel B: PRI", color(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g3.gph", replace
twoway (scatter share_prd_ln_runbin5 runbin5 if running>=-375 & running<=375, mcolor(gray)) ///
  (lfit share_prd_ln_runbin5 runbin5 if running>=-375 & running<=0, lcolor(black) clwidth(thick)) ///
  (lfit share_prd_ln_runbin5 runbin5 if running>=0 & running<=375, lcolor(black) clwidth(thick)), ///
  xline(0, lwidth(thick) lpattern(dash) lcolor(black)) legend(off) ylabel(, nogrid) ytitle(PRD vote share) xtitle(Number of voters from splitting) title("Panel D: PRD", color(black)) ///
  subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph save Graph "g4.gph", replace
  
graph combine "g1" "g3" "g2" "g4", rows(2) cols(2) subtitle(, color(black) fcolor(white) lcolor(white)) ///
  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
capture graph export "C:\Users\John\Dropbox\Discontinuity\Paper Writing\discontinuity.pdf", as(pdf) replace
capture graph export "C:\Users\jmarshall\Dropbox\Discontinuity\Paper Writing\discontinuity.pdf", as(pdf) replace

erase "g1.gph" 
erase "g2.gph" 
erase "g3.gph" 
erase "g4.gph" 
restore



*** Effects of polling station split discontinuity (Table 2)
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  sum `y' if e(sample)==1
  estadd scalar Outcome_Mean=`r(mean)'
  estadd scalar Outcome_SD=`r(sd)'	
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)



*** Estimates of turnout buying effectiveness (for Table 4 of Online Appendix) - need to install ivreg2 package!
set matsize 4000
eststo clear
quietly foreach y of varlist share_pri_ln share_pan_ln share_prd_ln {
  eststo: xi: ivreg2 `y' (turnout = discontinuity) i.id_district_year if running>-20 & running<=20, cluster(id_estado)
  matrix A = e(first) 
  estadd scalar F_stat=A[3,1]
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N F_stat, fmt(0 1) labels("Observations" "First stage $ F$ statistic")) starlevels(* .1 ** .05 *** .01) keep(turnout) label varlabels(turnout "Turnout")



*** Simple regression estimates (Table 3)
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' polling_stations total_lista_nominal, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  sum `y' if e(sample)==1
  estadd scalar Outcome_Mean=`r(mean)'
  estadd scalar Outcome_SD=`r(sd)'	
}
estout, style(tex) cells(b(star fmt(6)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(polling_stations total_lista_nominal)



*** Focus specifically on PRD interactions with local strength (Table 5 in Online Appendix)
eststo clear
eststo: areg share_prd_ln discontinuity##prd_gov if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
g prd_stronghold = estado=="Guerrero" | estado=="Michoacn"
eststo: areg share_prd_ln discontinuity##prd_stronghold if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(1.discontinuity 1.discontinuity#1.prd_gov 1.discontinuity#1.prd_stronghold)



*** Heterogeneous effects of discontinuity with distance (Table 4 and Figure 8)
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  sum `y' if e(sample)==1
  estadd scalar Outcome_Mean=`r(mean)'
  estadd scalar Outcome_SD=`r(sd)'
  noisily matrix list e(V)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N Outcome_Mean Outcome_SD, fmt(0 2 2)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)

twoway (function y = 0.0034 + 0.0110 * x - 0.0030 * x^2, range(0 5) lcolor(black)) ///
  (function y = 0.0034 + 0.0110 * x - 0.0030 * x^2 + 1.96 * (1.181e-06 + .00001301 * x^2 + 1.613e-06 * x^4 - 2 * 7.288e-07 * x + 2 * 7.739e-08 * x^2 - 2 * 4.134e-06 * x^3)^0.5, range(0 5) lpattern(dash) lcolor(black)) ///
  (function y = 0.0034 + 0.0110 * x - 0.0030 * x^2 - 1.96 * (1.181e-06 + .00001301 * x^2 + 1.613e-06 * x^4 - 2 * 7.288e-07 * x + 2 * 7.739e-08 * x^2 - 2 * 4.134e-06 * x^3)^0.5, range(0 5) lpattern(dash) lcolor(black)), ///
  yline(0, lpattern(dash) lcolor(black)) legend(off) ylabel(, nogrid) ytitle(Marginal effect of splitting on PRI vote share) xtitle(Average distance to polling station (km)) subtitle(, color(black) fcolor(white) lcolor(white)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))



*****************************************
***         Robustness checks         ***
*****************************************

*** Different bandwidths (Figure 9)
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo clear
  noisily di "Bandwidth checks: Outcome = `y'"
  quietly forvalues b=5(5)100 {
    eststo, title("b=`b'"): areg `y' discontinuity if running>-`b' & running<=`b', vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  }
  noisily estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)
}

* Paste the following table in Stata as additional data
bandwidth	est	se
5	0.0124	0.003
10	0.0095	0.0018
15	0.009	0.0016
20	0.0085	0.0012
25	0.0087	0.0009
30	0.0079	0.0009
35	0.0071	0.0011
40	0.0066	0.001
45	0.0064	0.001
50	0.0062	0.001
55	0.0063	0.0009
60	0.0064	0.0009
65	0.0066	0.0009
70	0.0065	0.0009
75	0.0064	0.0009
80	0.0061	0.0008
85	0.0061	0.0008
90	0.0061	0.0008
95	0.0058	0.0007
100	0.0058	0.0006

g min95 = est - 1.96 * se
g max95 = est + 1.96 * se

twoway (scatter est bandwidth, mcolor(black)) (rcap min95 max95 bandwidth, lcolor(black)), title("Panel A: turnout", color(black)) ///
  ytitle("Marginal effect of split") legend(off) graphregion(fcolor(white) lcolor(white)) ylab(, nogrid) xtitle("Bandwidth") yline(0, lpattern(dash) lcolor(black))
graph save Graph "g1.gph", replace
  
drop bandwidth-max95

* Paste the following table in Stata as additional data
bandwidth	est	se
5	0.0029	0.0024
10	0.0046	0.0018
15	0.0044	0.0013
20	0.0045	0.0011
25	0.0044	0.0008
30	0.0045	0.0008
35	0.0046	0.0008
40	0.0042	0.0009
45	0.0039	0.0008
50	0.0034	0.0008
55	0.0031	0.0007
60	0.0028	0.0008
65	0.0031	0.0007
70	0.003	0.0006
75	0.0028	0.0006
80	0.0028	0.0005
85	0.0027	0.0006
90	0.0029	0.0005
95	0.0028	0.0005
100	0.0028	0.0005

g min95 = est - 1.96 * se
g max95 = est + 1.96 * se

twoway (scatter est bandwidth, mcolor(black)) (rcap min95 max95 bandwidth, lcolor(black)), title("Panel B: PRI", color(black)) ///
  ytitle("Marginal effect of split") legend(off) graphregion(fcolor(white) lcolor(white)) ylab(, nogrid) xtitle("Bandwidth") yline(0, lpattern(dash) lcolor(black))
graph save Graph "g2.gph", replace
  
drop bandwidth-max95

* Paste the following table in Stata as additional data
bandwidth	est	se
5	0.0112	0.0035
10	0.0059	0.0026
15	0.004	0.0019
20	0.0041	0.0017
25	0.0037	0.0011
30	0.0024	0.0008
35	0.0017	0.0009
40	0.0016	0.0007
45	0.0019	0.0008
50	0.0019	0.0008
55	0.002	0.0007
60	0.0024	0.0006
65	0.0023	0.0006
70	0.0023	0.0006
75	0.0023	0.0005
80	0.002	0.0005
85	0.0019	0.0005
90	0.0018	0.0005
95	0.0015	0.0004
100	0.0015	0.0005

g min95 = est - 1.96 * se
g max95 = est + 1.96 * se

twoway (scatter est bandwidth, mcolor(black)) (rcap min95 max95 bandwidth, lcolor(black)), title("Panel C: PAN", color(black)) ///
  ytitle("Marginal effect of split") legend(off) graphregion(fcolor(white) lcolor(white)) ylab(, nogrid) xtitle("Bandwidth") yline(0, lpattern(dash) lcolor(black))
graph save Graph "g3.gph", replace
  
drop bandwidth-max95

* Paste the following table in Stata as additional data
bandwidth	est	se
5	-0.0032	0.002
10	-0.001	0.001
15	0.0006	0.0007
20	0.0003	0.0008
25	0.0006	0.0006
30	0.0007	0.0007
35	0.0005	0.0007
40	0.0002	0.0006
45	0.0003	0.0005
50	0.0004	0.0005
55	0.0005	0.0005
60	0.0003	0.0005
65	0.0003	0.0004
70	0.0004	0.0004
75	0.0003	0.0004
80	0.0004	0.0004
85	0.0004	0.0004
90	0.0005	0.0003
95	0.0005	0.0003
100	0.0005	0.0002

g min95 = est - 1.96 * se
g max95 = est + 1.96 * se

twoway (scatter est bandwidth, mcolor(black)) (rcap min95 max95 bandwidth, lcolor(black)), title("Panel D: PRD", color(black)) ///
  ytitle("Marginal effect of split") legend(off) graphregion(fcolor(white) lcolor(white)) ylab(, nogrid) xtitle("Bandwidth") yline(0, lpattern(dash) lcolor(black))
graph save Graph "g4.gph", replace
  
drop bandwidth-max95

graph combine "g1" "g2" "g3" "g4", rows(2) cols(2) subtitle(, color(black) fcolor(white) lcolor(white)) ///
  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

erase "g1.gph" 
erase "g2.gph" 
erase "g3.gph" 
erase "g4.gph" 



quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo clear
  noisily di "Bandwidth checks: Outcome = `y'"
  quietly forvalues b=5(5)100 {
    eststo, title("b=`b'"): areg `y' discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq if running>-`b' & running<=`b', vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  }
  noisily estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)
}



*** Local linear regressions (Table 6 in Online Appendix)
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity discontinuity##c.running if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)



eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity discontinuity##c.running weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)



*** Control linearly for balance variables (Table 7 in Online Appendix)
global controls "lag_pri lag_pan lag_prd log_area voter_density weighted_distance share_pea-share_soc_sec illiterate_above_15 pri_inc-share_viv_part_hab share_viv_all-share_viv_inter"

eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity $controls if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity)

eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq $controls if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)



*** Control for quadratic interactions at the discontinuity (Table 8 in Online Appendix)
quietly foreach x of varlist lag_pri lag_pan lag_prd log_area voter_density weighted_distance share_pea-share_soc_sec illiterate_above_15 pri_inc-share_viv_part_hab share_viv_all-share_viv_inter {
  eststo clear
  noisily di "Discontinuity interaction with quadratic in `x'"
  foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
    eststo, title("`y'"): areg `y' discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq discontinuity##c.`x'##c.`x' if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year)
  }
  noisily estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)
}



*** District-discontinuity fixed effects (need to cluster by district instead) (Table 9 in Online Appendix)
set matsize 10000
egen id_district_year_discontinuity = group(id_district_year discontinuity)
eststo clear
quietly foreach y of varlist turnout share_pri_ln share_pan_ln share_prd_ln {
  eststo, title("`y'"): areg `y' discontinuity discontinuity##id_district if running>-20 & running<=20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year_discontinuity)
  eststo, title("`y'"): areg `y' discontinuity discontinuity##id_district weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq if running>-20 & running<20, vce(bootstrap, cluster(id_estado) reps(1000)) a(id_district_year_discontinuity)
}
estout, style(tex) cells(b(star fmt(4)) se(par)) stats(N, fmt(0)) label legend starlevels(* 0.1 ** 0.05 *** 0.01) keep(discontinuity weighted_distance weighted_distance_sq discontinuity_weighted_distance disc_weighted_distance_sq)
